@@ -37,10 +37,9 @@ class LiveJournalAuth(OpenIdAuth):
 
     def openid_url(self):
         """Returns LiveJournal authentication URL"""
-        if self.request.method != 'POST' or \
-           not self.request.POST.get(LIVEJOURNAL_USER_FIELD):
+        if not self.data.get(LIVEJOURNAL_USER_FIELD):
             raise ValueError, 'Missing LiveJournal user identifier'
-        return LIVEJOURNAL_URL % self.request.POST[LIVEJOURNAL_USER_FIELD]
+        return LIVEJOURNAL_URL % self.data[LIVEJOURNAL_USER_FIELD]
 
 
 # Backend definition
